import type { Knex } from 'knex';
import { Model } from 'objection';
import { PGDispatcher } from './dispatcher';
import type { ExLogger } from './types';
export interface CoreDBDispatcherOptions {
    healthcheckInterval?: number;
    healthcheckTimeout?: number;
    suppressStatusLogs?: boolean;
    beforeTerminate?: () => Promise<void>;
}
export interface CoreDBConstructorArgs {
    connectionString: string;
    dispatcherOptions?: CoreDBDispatcherOptions;
    knexOptions?: Knex.Config;
    logger?: ExLogger;
}
export declare function getModel(): {
    new (): {
        readonly primary: Knex<any, any[]>;
        readonly replica: Knex<any, any[]>;
        $modelClass: import("objection").ModelClass<any>;
        $relatedQuery<K extends keyof any>(relationName: K, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").RelatedQueryBuilder<any[K]>;
        $relatedQuery<RM extends Model>(relationName: string, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<RM>;
        $query(trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilder<any, any>;
        $id(id: any): void;
        $id(): any;
        $fetchGraph(expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").QueryBuilder<any, any>;
        $formatDatabaseJson(json: import("objection").Pojo): import("objection").Pojo;
        $parseDatabaseJson(json: import("objection").Pojo): import("objection").Pojo;
        $formatJson(json: import("objection").Pojo): import("objection").Pojo;
        $parseJson(json: import("objection").Pojo, opt?: import("objection").ModelOptions | undefined): import("objection").Pojo;
        $beforeValidate(jsonSchema: import("objection").JSONSchema, json: import("objection").Pojo, opt: import("objection").ModelOptions): import("objection").JSONSchema;
        $validate(json?: import("objection").Pojo | undefined, opt?: import("objection").ModelOptions | undefined): import("objection").Pojo;
        $afterValidate(json: import("objection").Pojo, opt: import("objection").ModelOptions): void;
        $beforeInsert(queryContext: import("objection").QueryContext): void | Promise<any>;
        $afterInsert(queryContext: import("objection").QueryContext): void | Promise<any>;
        $afterUpdate(opt: import("objection").ModelOptions, queryContext: import("objection").QueryContext): void | Promise<any>;
        $beforeUpdate(opt: import("objection").ModelOptions, queryContext: import("objection").QueryContext): void | Promise<any>;
        $afterGet(queryContext: import("objection").QueryContext): void | Promise<any>;
        $afterFind(queryContext: import("objection").QueryContext): void | Promise<any>;
        $beforeDelete(queryContext: import("objection").QueryContext): void | Promise<any>;
        $afterDelete(queryContext: import("objection").QueryContext): void | Promise<any>;
        $toDatabaseJson(): import("objection").Pojo;
        $toJson(opt?: import("objection").ToJsonOptions | undefined): import("objection").ModelObject<any>;
        toJSON(opt?: import("objection").ToJsonOptions | undefined): import("objection").ModelObject<any>;
        $setJson(json: object, opt?: import("objection").ModelOptions | undefined): any;
        $setDatabaseJson(json: object): any;
        $setRelated<RM_1 extends Model>(relation: String | import("objection").Relation, related: RM_1 | RM_1[] | null | undefined): any;
        $appendRelated<RM_2 extends Model>(relation: String | import("objection").Relation, related: RM_2 | RM_2[] | null | undefined): any;
        $set(obj: import("objection").Pojo): any;
        $omit(keys: string | string[] | {
            [key: string]: boolean;
        }): any;
        $pick(keys: string | string[] | {
            [key: string]: boolean;
        }): any;
        $clone(opt?: import("objection").CloneOptions | undefined): any;
        $traverse(filterConstructor: typeof Model, traverser: import("objection").TraverserFunction): any;
        $traverse(traverser: import("objection").TraverserFunction): any;
        $traverseAsync(filterConstructor: typeof Model, traverser: import("objection").TraverserFunction): Promise<any>;
        $traverseAsync(traverser: import("objection").TraverserFunction): Promise<any>;
        $knex(): Knex<any, any[]>;
        $transaction(): Knex<any, any[]>;
        QueryBuilderType: import("objection").QueryBuilder<any, any[]>;
    };
    db: PGDispatcher;
    readonly primary: Knex<any, any[]>;
    readonly replica: Knex<any, any[]>;
    QueryBuilder: typeof import("objection").QueryBuilder;
    tableName: string;
    idColumn: string | string[];
    jsonSchema: import("objection").JSONSchema;
    relationMappings: import("objection").RelationMappings | import("objection").RelationMappingsThunk;
    modelPaths: string[];
    jsonAttributes: string[];
    virtualAttributes: string[];
    uidProp: string;
    uidRefProp: string;
    dbRefProp: string;
    propRefRegex: RegExp;
    pickJsonSchemaProperties: boolean;
    relatedFindQueryMutates: boolean;
    relatedInsertQueryMutates: boolean;
    useLimitInFirst: boolean;
    modifiers: import("objection").Modifiers<import("objection").AnyQueryBuilder>;
    columnNameMappers: import("objection").ColumnNameMappers;
    raw: import("objection").RawFunction;
    ref: import("objection").ReferenceFunction;
    fn: import("objection").FunctionFunction;
    BelongsToOneRelation: import("objection").RelationType;
    HasOneRelation: import("objection").RelationType;
    HasManyRelation: import("objection").RelationType;
    ManyToManyRelation: import("objection").RelationType;
    HasOneThroughRelation: import("objection").RelationType;
    defaultGraphOptions?: import("objection").GraphOptions | undefined;
    query<M_1 extends Model>(this: import("objection").Constructor<M_1>, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<M_1>;
    relatedQuery<M_2 extends Model, K_1 extends keyof M_2>(this: import("objection").Constructor<M_2>, relationName: K_1, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").ArrayRelatedQueryBuilder<M_2[K_1]>;
    relatedQuery<RM_3 extends Model>(relationName: string, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<RM_3>;
    fromJson<M_3 extends Model>(this: import("objection").Constructor<M_3>, json: object, opt?: import("objection").ModelOptions | undefined): M_3;
    fromDatabaseJson<M_4 extends Model>(this: import("objection").Constructor<M_4>, json: object): M_4;
    createValidator(): import("objection").Validator;
    createValidationError(args: import("objection").CreateValidationErrorArgs): Error;
    createNotFoundError(queryContext: import("objection").QueryContext, args: import("objection").CreateNotFoundErrorArgs): Error;
    tableMetadata(opt?: import("objection").TableMetadataOptions | undefined): import("objection").TableMetadata;
    fetchTableMetadata(opt?: import("objection").FetchTableMetadataOptions | undefined): Promise<import("objection").TableMetadata>;
    knex(knex?: Knex<any, any[]> | undefined): Knex<any, any[]>;
    knexQuery(): Knex.QueryBuilder<any, any>;
    startTransaction(knexOrTransaction?: import("objection").TransactionOrKnex | undefined): Promise<import("objection").Transaction>;
    transaction<T>(callback: (trx: import("objection").Transaction) => Promise<T>): Promise<T>;
    transaction<T_1>(trxOrKnex: import("objection").TransactionOrKnex, callback: (trx: import("objection").Transaction) => Promise<T_1>): Promise<T_1>;
    bindKnex<M_5>(this: M_5, trxOrKnex: import("objection").TransactionOrKnex): M_5;
    bindTransaction<M_6>(this: M_6, trxOrKnex: import("objection").TransactionOrKnex): M_6;
    fetchGraph<M_7 extends Model>(this: import("objection").Constructor<M_7>, modelOrObject: import("objection").PartialModelObject<M_7>, expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").SingleQueryBuilder<import("objection").QueryBuilderType<M_7>>;
    fetchGraph<M_8 extends Model>(this: import("objection").Constructor<M_8>, modelOrObject: import("objection").PartialModelObject<M_8>[], expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").QueryBuilderType<M_8>;
    getRelations(): import("objection").Relations;
    getRelation(name: string): import("objection").Relation;
    traverse(models: Model | Model[], traverser: import("objection").TraverserFunction): void;
    traverse(filterConstructor: typeof Model, models: Model | Model[], traverser: import("objection").TraverserFunction): void;
    traverseAsync(models: Model | Model[], traverser: import("objection").TraverserFunction): Promise<void>;
    traverseAsync(filterConstructor: typeof Model, models: Model | Model[], traverser: import("objection").TraverserFunction): Promise<void>;
    beforeFind(args: import("objection").StaticHookArguments<any, any>): any;
    afterFind(args: import("objection").StaticHookArguments<any, any>): any;
    beforeInsert(args: import("objection").StaticHookArguments<any, any>): any;
    afterInsert(args: import("objection").StaticHookArguments<any, any>): any;
    beforeUpdate(args: import("objection").StaticHookArguments<any, any>): any;
    afterUpdate(args: import("objection").StaticHookArguments<any, any>): any;
    beforeDelete(args: import("objection").StaticHookArguments<any, any>): any;
    afterDelete(args: import("objection").StaticHookArguments<any, any>): any;
};
export declare function initDB({ connectionString, dispatcherOptions, knexOptions, logger, }: CoreDBConstructorArgs): {
    db: PGDispatcher;
    CoreBaseModel: {
        new (): {
            readonly primary: Knex<any, any[]>;
            readonly replica: Knex<any, any[]>;
            $modelClass: import("objection").ModelClass<any>;
            $relatedQuery<K extends keyof any>(relationName: K, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").RelatedQueryBuilder<any[K]>;
            $relatedQuery<RM extends Model>(relationName: string, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<RM>;
            $query(trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilder<any, any>;
            $id(id: any): void;
            $id(): any;
            $fetchGraph(expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").QueryBuilder<any, any>;
            $formatDatabaseJson(json: import("objection").Pojo): import("objection").Pojo;
            $parseDatabaseJson(json: import("objection").Pojo): import("objection").Pojo;
            $formatJson(json: import("objection").Pojo): import("objection").Pojo;
            $parseJson(json: import("objection").Pojo, opt?: import("objection").ModelOptions | undefined): import("objection").Pojo;
            $beforeValidate(jsonSchema: import("objection").JSONSchema, json: import("objection").Pojo, opt: import("objection").ModelOptions): import("objection").JSONSchema;
            $validate(json?: import("objection").Pojo | undefined, opt?: import("objection").ModelOptions | undefined): import("objection").Pojo;
            $afterValidate(json: import("objection").Pojo, opt: import("objection").ModelOptions): void;
            $beforeInsert(queryContext: import("objection").QueryContext): void | Promise<any>;
            $afterInsert(queryContext: import("objection").QueryContext): void | Promise<any>;
            $afterUpdate(opt: import("objection").ModelOptions, queryContext: import("objection").QueryContext): void | Promise<any>;
            $beforeUpdate(opt: import("objection").ModelOptions, queryContext: import("objection").QueryContext): void | Promise<any>;
            $afterGet(queryContext: import("objection").QueryContext): void | Promise<any>;
            $afterFind(queryContext: import("objection").QueryContext): void | Promise<any>;
            $beforeDelete(queryContext: import("objection").QueryContext): void | Promise<any>;
            $afterDelete(queryContext: import("objection").QueryContext): void | Promise<any>;
            $toDatabaseJson(): import("objection").Pojo;
            $toJson(opt?: import("objection").ToJsonOptions | undefined): import("objection").ModelObject<any>;
            toJSON(opt?: import("objection").ToJsonOptions | undefined): import("objection").ModelObject<any>;
            $setJson(json: object, opt?: import("objection").ModelOptions | undefined): any;
            $setDatabaseJson(json: object): any;
            $setRelated<RM_1 extends Model>(relation: String | import("objection").Relation, related: RM_1 | RM_1[] | null | undefined): any;
            $appendRelated<RM_2 extends Model>(relation: String | import("objection").Relation, related: RM_2 | RM_2[] | null | undefined): any;
            $set(obj: import("objection").Pojo): any;
            $omit(keys: string | string[] | {
                [key: string]: boolean;
            }): any;
            $pick(keys: string | string[] | {
                [key: string]: boolean;
            }): any;
            $clone(opt?: import("objection").CloneOptions | undefined): any;
            $traverse(filterConstructor: typeof Model, traverser: import("objection").TraverserFunction): any;
            $traverse(traverser: import("objection").TraverserFunction): any;
            $traverseAsync(filterConstructor: typeof Model, traverser: import("objection").TraverserFunction): Promise<any>;
            $traverseAsync(traverser: import("objection").TraverserFunction): Promise<any>;
            $knex(): Knex<any, any[]>;
            $transaction(): Knex<any, any[]>;
            QueryBuilderType: import("objection").QueryBuilder<any, any[]>;
        };
        db: PGDispatcher;
        readonly primary: Knex<any, any[]>;
        readonly replica: Knex<any, any[]>;
        QueryBuilder: typeof import("objection").QueryBuilder;
        tableName: string;
        idColumn: string | string[];
        jsonSchema: import("objection").JSONSchema;
        relationMappings: import("objection").RelationMappings | import("objection").RelationMappingsThunk;
        modelPaths: string[];
        jsonAttributes: string[];
        virtualAttributes: string[];
        uidProp: string;
        uidRefProp: string;
        dbRefProp: string;
        propRefRegex: RegExp;
        pickJsonSchemaProperties: boolean;
        relatedFindQueryMutates: boolean;
        relatedInsertQueryMutates: boolean;
        useLimitInFirst: boolean;
        modifiers: import("objection").Modifiers<import("objection").AnyQueryBuilder>;
        columnNameMappers: import("objection").ColumnNameMappers;
        raw: import("objection").RawFunction;
        ref: import("objection").ReferenceFunction;
        fn: import("objection").FunctionFunction;
        BelongsToOneRelation: import("objection").RelationType;
        HasOneRelation: import("objection").RelationType;
        HasManyRelation: import("objection").RelationType;
        ManyToManyRelation: import("objection").RelationType;
        HasOneThroughRelation: import("objection").RelationType;
        defaultGraphOptions?: import("objection").GraphOptions | undefined;
        query<M_1 extends Model>(this: import("objection").Constructor<M_1>, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<M_1>;
        relatedQuery<M_2 extends Model, K_1 extends keyof M_2>(this: import("objection").Constructor<M_2>, relationName: K_1, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").ArrayRelatedQueryBuilder<M_2[K_1]>;
        relatedQuery<RM_3 extends Model>(relationName: string, trxOrKnex?: import("objection").TransactionOrKnex | undefined): import("objection").QueryBuilderType<RM_3>;
        fromJson<M_3 extends Model>(this: import("objection").Constructor<M_3>, json: object, opt?: import("objection").ModelOptions | undefined): M_3;
        fromDatabaseJson<M_4 extends Model>(this: import("objection").Constructor<M_4>, json: object): M_4;
        createValidator(): import("objection").Validator;
        createValidationError(args: import("objection").CreateValidationErrorArgs): Error;
        createNotFoundError(queryContext: import("objection").QueryContext, args: import("objection").CreateNotFoundErrorArgs): Error;
        tableMetadata(opt?: import("objection").TableMetadataOptions | undefined): import("objection").TableMetadata;
        fetchTableMetadata(opt?: import("objection").FetchTableMetadataOptions | undefined): Promise<import("objection").TableMetadata>;
        knex(knex?: Knex<any, any[]> | undefined): Knex<any, any[]>;
        knexQuery(): Knex.QueryBuilder<any, any>;
        startTransaction(knexOrTransaction?: import("objection").TransactionOrKnex | undefined): Promise<import("objection").Transaction>;
        transaction<T>(callback: (trx: import("objection").Transaction) => Promise<T>): Promise<T>;
        transaction<T_1>(trxOrKnex: import("objection").TransactionOrKnex, callback: (trx: import("objection").Transaction) => Promise<T_1>): Promise<T_1>;
        bindKnex<M_5>(this: M_5, trxOrKnex: import("objection").TransactionOrKnex): M_5;
        bindTransaction<M_6>(this: M_6, trxOrKnex: import("objection").TransactionOrKnex): M_6;
        fetchGraph<M_7 extends Model>(this: import("objection").Constructor<M_7>, modelOrObject: import("objection").PartialModelObject<M_7>, expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").SingleQueryBuilder<import("objection").QueryBuilderType<M_7>>;
        fetchGraph<M_8 extends Model>(this: import("objection").Constructor<M_8>, modelOrObject: import("objection").PartialModelObject<M_8>[], expression: import("objection").RelationExpression<M>, options?: import("objection").FetchGraphOptions | undefined): import("objection").QueryBuilderType<M_8>;
        getRelations(): import("objection").Relations;
        getRelation(name: string): import("objection").Relation;
        traverse(models: Model | Model[], traverser: import("objection").TraverserFunction): void;
        traverse(filterConstructor: typeof Model, models: Model | Model[], traverser: import("objection").TraverserFunction): void;
        traverseAsync(models: Model | Model[], traverser: import("objection").TraverserFunction): Promise<void>;
        traverseAsync(filterConstructor: typeof Model, models: Model | Model[], traverser: import("objection").TraverserFunction): Promise<void>;
        beforeFind(args: import("objection").StaticHookArguments<any, any>): any;
        afterFind(args: import("objection").StaticHookArguments<any, any>): any;
        beforeInsert(args: import("objection").StaticHookArguments<any, any>): any;
        afterInsert(args: import("objection").StaticHookArguments<any, any>): any;
        beforeUpdate(args: import("objection").StaticHookArguments<any, any>): any;
        afterUpdate(args: import("objection").StaticHookArguments<any, any>): any;
        beforeDelete(args: import("objection").StaticHookArguments<any, any>): any;
        afterDelete(args: import("objection").StaticHookArguments<any, any>): any;
    };
    helpers: {
        clearDatabase: () => Promise<void>;
        rollbackDatabase: () => Promise<void>;
        migrateDatabase: () => Promise<void>;
        prepareDatabase: () => Promise<void>;
    };
};
